@@ -49,27 +49,27 @@ $ABSTRACT = 'Sim::OPT::Descent is an module collaborating with the Sim::OPT modu
 
 sub descend 
 {
-	my $swap = shift; #say TOFILE "swapINDESCEND: " . dump($swap);
+	my $swap = shift; 
 	my %dat = %$swap;
-	my @instances = @{ $dat{instances} }; #say "scalar(\@instances): " . scalar(@instances);
-	my $countcase = $dat{countcase}; #say "dump(\$countcase): " . dump($countcase); # IT WILL BE SHADOWED. CUT ZZZ
-	my $countblock = $dat{countblock}; #say "dump(\$countblock): " . dump($countblock); # IT WILL BE SHADOWED. CUT ZZZ		
-	my %dirfiles = %{ $dat{dirfiles} }; #say "dump(\%dirfiles): " . dump(%dirfiles); 
+	my @instances = @{ $dat{instances} }; 
+	my $countcase = $dat{countcase}; 
+	my $countblock = $dat{countblock}; 
+	my %dirfiles = %{ $dat{dirfiles} }; 
 	my $repfile = $dat{repfile}; 
 		
-	$configfile = $main::configfile; #say "dump(\$configfile): " . dump($configfile);
-	@sweeps = @main::sweeps; #say "dump(\@sweeps): " . dump(@sweeps);
-	@varinumbers = @main::varinumbers; #say "dump(\@varinumbers): " . dump(@varinumbers);
+	$configfile = $main::configfile; 
+	@sweeps = @main::sweeps; 
+	@varinumbers = @main::varinumbers; 
 	@mediumiters = @main::mediumiters;
-	@rootnames = @main::rootnames; #say "dump(\@rootnames): " . dump(@rootnames);
-	%vals = %main::vals; #say "dump(\%vals): " . dump(%vals);
+	@rootnames = @main::rootnames; 
+	%vals = %main::vals; 
 	
-	$mypath = $main::mypath;  #say TOFILE "dumpINDESCEND(\$mypath): " . dump($mypath);
-	$exeonfiles = $main::exeonfiles; #say TOFILE "dumpINDESCEND(\$exeonfiles): " . dump($exeonfiles);
+	$mypath = $main::mypath;  
+	$exeonfiles = $main::exeonfiles; 
 	$generatechance = $main::generatechance; 
 	$file = $main::file;
 	$preventsim = $main::preventsim;
-	$fileconfig = $main::fileconfig; #say TOFILE "dumpINDESCEND(\$fileconfig): " . dump($fileconfig); # NOW GLOBAL. TO MAKE IT PRIVATE, FIX PASSING OF PARAMETERS IN CONTRAINTS PROPAGATION SECONDARY SUBROUTINES
+	$fileconfig = $main::fileconfig; 
 	$outfile = $main::outfile;
 	$tofile = $main::tofile;
 	$report = $main::report;
@@ -81,10 +81,10 @@ sub descend
 	say "\nNow in Sim::OPT::Descend.\n";
 	say $tee "\n#Now in Sim::OPT::Descend.\n";
 	
-	#say TOFILE "dump(\$repfile): " . dump($repfile); 
+	
 	%dowhat = %main::dowhat;
 
-	%simtitles = %main::simtitles; #say "dumpINDESCEND(\@simtitles): " . dump(@simtitles);
+	%simtitles = %main::simtitles; 
 	%retrievedata = %main::retrievedata;
 	@keepcolumns = @main::keepcolumns;
 	@weights = @main::weights;
@@ -103,33 +103,33 @@ sub descend
 	@filter_columns = @main::filter_columns;
 	%vals = %main::vals;
 	
-	my @simcases = @{ $dirfiles{simcases} }; #say "dump(\@simcases): " . dump(@simcases);
-	my @simstruct = @{ $dirfiles{simstruct} }; #say "dump(\@simstruct): " . dump(@simstruct);
+	my @simcases = @{ $dirfiles{simcases} }; 
+	my @simstruct = @{ $dirfiles{simstruct} }; 
 	my @morphcases = @{ $dirfiles{morphcases} };
 	my @morphstruct = @{ $dirfiles{morphstruct} };
-	my @retcases = @{ $dirfiles{retcases} }; #say TOFILE "dumpINDESCEND2(\@retcases): " . dump(@retcases);
-	my @retstruct = @{ $dirfiles{retstruct} }; #say TOFILE"dump(\@retstruct): " . dump(@retstruct);
-	my @repcases = @{ $dirfiles{repcases} };  #say TOFILE"dumpINDESCEND(\@repcases): " . dump(@repcases);
-	my @repstruct = @{ $dirfiles{repstruct} }; #say TOFILE"dumpINDESCEND(\@repstruct): " . dump(@repstruct);
-	my @mergecases = @{ $dirfiles{mergecases} }; #say TOFILE"dumpINDESCEND(\@mergecases): " . dump(@mergecases);
-	my @mergestruct = @{ $dirfiles{mergestruct} }; #say TOFILE"dumpINDESCEND(\@mergestruct): " . dump(@mergestruct);
-	my @descendcases = @{ $dirfiles{descendcases} }; #say TOFILE"dumpINDESCEND(\@descendcases): " . dump(@descendcases);
-	my @descendstruct = @{ $dirfiles{descendstruct} }; #say TOFILE"dumpINDESCEND(\@descendstruct): " . dump(@descendstruct);
+	my @retcases = @{ $dirfiles{retcases} }; 
+	my @retstruct = @{ $dirfiles{retstruct} }; 
+	my @repcases = @{ $dirfiles{repcases} };  
+	my @repstruct = @{ $dirfiles{repstruct} }; 
+	my @mergecases = @{ $dirfiles{mergecases} }; 
+	my @mergestruct = @{ $dirfiles{mergestruct} }; 
+	my @descendcases = @{ $dirfiles{descendcases} }; 
+	my @descendstruct = @{ $dirfiles{descendstruct} }; 
 	
-	my $morphlist = $dirfiles{morphlist}; #say "dump(\$dat{morphlist}): " . dump($dat{morphlist});
+	my $morphlist = $dirfiles{morphlist}; 
 	my $morphblock = $dirfiles{morphblock};
-	my $simlist = $dirfiles{simlist}; #say "dump(\$simlist): " . dump($simlist);
+	my $simlist = $dirfiles{simlist}; 
 	my $simblock = $dirfiles{simblock};
 	my $retlist = $dirfiles{retlist};
 	my $retblock = $dirfiles{retblock};
-	my $replist = $dirfiles{replist}; #say TOFILE"dumpINDESCEND(\$replist): " . dump($replist);
-	my $repblock = $dirfiles{repblock}; #say TOFILE"dumpINDESCEND(\$repblock): " . dump($repblock);
-	my $descendlist = $dirfiles{descendlist}; #say TOFILE"dumpINDESCEND(\$descendlist): " . dump($descendlist);
-	my $descendblock = $dirfiles{descendblock}; #say TOFILE"dumpINDESCEND(\$descendblock): " . dump($descendblock);
+	my $replist = $dirfiles{replist}; 
+	my $repblock = $dirfiles{repblock}; 
+	my $descendlist = $dirfiles{descendlist}; 
+	my $descendblock = $dirfiles{descendblock}; 
 	
-	my $skipfile = $vals{skipfile}; #say TOFILE "dump(\$skipfile): " . dump($skipfile);
-	my $skipsim = $vals{skipsim}; #say TOFILE "dump(\$skipsim): " . dump($skipsim);
-	my $skipreport = $vals{skipreport}; #say TOFILE "dump(\$skipreport): " . dump($skipreport);
+	my $skipfile = $vals{skipfile}; 
+	my $skipsim = $vals{skipsim}; 
+	my $skipreport = $vals{skipreport}; 
 		
 	#my $getpars = shift;
 	#eval( $getpars );
@@ -142,49 +142,49 @@ sub descend
 	my $instance = $instances[0]; # THIS WOULD HAVE TO BE A LOOP HERE TO MIX ALL THE MERGECASES!!! ### ZZZ
 	
 	my %d = %{$instance};
-	my $countcase = $d{countcase}; #say TOFILE "dump(\$countcase): " . dump($countcase);
-	my $countblock = $d{countblock}; #say TOFILE "dump(\$countblock): " . dump($countblock);
-	my @miditers = @{ $d{miditers} }; #say TOFILE "BEGINDESCENDdump(\@miditers): " . dump(@miditers);
-	my @winneritems = @{ $d{winneritems} }; #say TOFILE "dumpIN( \@winneritems) " . dump(@winneritems);
-	my $countvar = $d{countvar}; #say TOFILE "dump(\$countvar): " . dump($countvar);
+	my $countcase = $d{countcase}; 
+	my $countblock = $d{countblock}; 
+	my @miditers = @{ $d{miditers} }; 
+	my @winneritems = @{ $d{winneritems} }; 
+	my $countvar = $d{countvar}; 
 	my $countstep = $d{countstep}; say TOFILE "dump(\$countstep): " . dump($countstep);						
-	my $to = $d{to}; #say TOFILE "dump(\$to): " . dump($to);
-	my $origin = $d{origin}; #say TOFILE "dump(\$origin): " . dump($origin);
-	my @uplift = @{ $d{uplift} }; #say TOFILE "dump(\@uplift): " . dump(@uplift);
+	my $to = $d{to}; 
+	my $origin = $d{origin}; 
+	my @uplift = @{ $d{uplift} }; 
 	#eval($getparshere);
 	
-	my $skip = $vals{$countvar}{skip}; #say TOFILE "dumpinreport(\$skip): " . dump($skip);
+	my $skip = $vals{$countvar}{skip}; 
 	
-	my $rootname = Sim::OPT::getrootname(\@rootnames, $countcase); #say TOFILE "dump(\$rootname): " . dump($rootname);
-	my @blockelts = Sim::OPT::getblockelts(\@sweeps, $countcase, $countblock); #say TOFILE "dumpIN( \@blockelts) " . dump(@blockelts);
-	my @blocks = Sim::OPT::getblocks(\@sweeps, $countcase);  #say TOFILE "dumpIN( \@blocks) " . dump(@blocks);
-	my $toitem = Sim::OPT::getitem(\@winneritems, $countcase, $countblock); #say TOFILE "dump(\$toitem): " . dump($toitem);
-	my $from = Sim::OPT::getline($toitem); #say TOFILE "dumpIN(\$from): " . dump($from);
-	my %varnums = Sim::OPT::getcase(\@varinumbers, $countcase); #say TOFILE "dumpIN---(\%varnums): " . dump(%varnums); 
-	my %mids = Sim::OPT::getcase(\@miditers, $countcase); #say TOFILE "dumpIN---(\%mids): " . dump(%mids); 
+	my $rootname = Sim::OPT::getrootname(\@rootnames, $countcase); 
+	my @blockelts = Sim::OPT::getblockelts(\@sweeps, $countcase, $countblock); 
+	my @blocks = Sim::OPT::getblocks(\@sweeps, $countcase);  
+	my $toitem = Sim::OPT::getitem(\@winneritems, $countcase, $countblock); 
+	my $from = Sim::OPT::getline($toitem); 
+	my %varnums = Sim::OPT::getcase(\@varinumbers, $countcase); 
+	my %mids = Sim::OPT::getcase(\@miditers, $countcase); 
 	#eval($getfly);
 	
-	my $stepsvar = Sim::OPT::getstepsvar($countvar, $countcase, \@varinumbers); #say TOFILE "dump(\$stepsvar): " . dump($stepsvar); 
-	my $varnumber = $countvar; #say TOFILE "dump---(\$varnumber): " . dump($varnumber) . "\n\n";  # LEGACY VARIABLE
+	my $stepsvar = Sim::OPT::getstepsvar($countvar, $countcase, \@varinumbers); 
+	my $varnumber = $countvar; 
 	my $contblocksplus = ($countblock + 1);
 	my $countcaseplus = ($countcase + 1);
 	
 	say $tee "Descending into case $countcaseplus, block $contblocksplus.";
 
-	my @columns_to_report = @{ $reporttempsdata[1] };  #say TOFILE "dump(\@columns_to_report): " . dump(@columns_to_report); 
-	my $number_of_columns_to_report = scalar(@columns_to_report); #say TOFILE "dump(\$number_of_columns_to_report): " . dump($number_of_columns_to_report); 
-	my $number_of_dates_to_mix = scalar(@simtitles); #say TOFILE "dump(\$number_of_dates_to_mix): " . dump($number_of_dates_to_mix); 
-	my @dates                    = @simtitles; #say TOFILE "dump(\@dates): " . dump(@dates); 
+	my @columns_to_report = @{ $reporttempsdata[1] };  
+	my $number_of_columns_to_report = scalar(@columns_to_report); 
+	my $number_of_dates_to_mix = scalar(@simtitles); 
+	my @dates                    = @simtitles; 
 
-	my $cleanmixed = "$repfile-clean.csv"; #say TOFILE "dump(\$cleanmixed): " . dump($cleanmixed); 
+	my $cleanmixed = "$repfile-clean.csv"; 
 	my $throwclean = $cleanmixed; $throwclean =~ s/\.csv//;
-	my $selectmixed = "$throwclean-select.csv"; #say TOFILE "dump(\$selectmixed): " . dump($selectmixed); 
+	my $selectmixed = "$throwclean-select.csv"; 
 	
 	sub cleanselect
 	{ 	# IT CLEANS THE MIXED FILE AND SELECTS SOME COLUMNS, THEN COPIES THEM IN ANOTHER FILE
 		say $tee "Cleaning results for case $countcaseplus, block $contblocksplus.";
 		open( MIXFILE, $repfile ) or die( "$!" ); say TOFILE "dump(\$repfile IN SUB cleanselect): " . dump($repfile); 
-		my @lines = <MIXFILE>; #say TOFILE "dump(MIXFILE \@lines): " . dump(@lines); 
+		my @lines = <MIXFILE>; 
 		close MIXFILE;
 		open( CLEANMIXED, ">$cleanmixed" ) or die( "$!" );
 		foreach my $line ( @lines )
@@ -198,7 +198,7 @@ sub descend
 	
 		# IT SELECTS SOME COLUMNS AND COPIES THEM IN ANOTHER FILE
 		open( CLEANMIXED, $cleanmixed ) or die( "$!" );
-		my @lines = <CLEANMIXED>; #say TOFILE "dump(CLEANMIXED \@lines): " . dump(@lines); 
+		my @lines = <CLEANMIXED>; 
 		close CLEANMIXED;
 		
 		open( SELECTEDMIXED, ">$selectmixed" ) or die( "$!" );
@@ -206,7 +206,7 @@ sub descend
 		{
 			my @elts = split(/\s+|,/, $line); ### DDD
 			$elts[0] =~ /^(.*)_-(.*)/;
-			my $touse = $1; #say "dump(CLEANMIXED \$touse): " . dump($touse); 
+			my $touse = $1; 
 			$touse =~ s/$mypath\///;
 			print SELECTEDMIXED "$touse,";
 			my $countout = 0;
@@ -243,12 +243,12 @@ sub descend
 	&cleanselect();
 	
 	my $throw = $selectmixed; $throw =~ s/\.csv//;
-	my $weight = "$throw-weight.csv"; #say TOFILE "dump(\$weight): " . dump($weight);  # THIS WILL HOST PARTIALLY SCALED VALUES, MADE POSITIVE AND WITH A CEILING OF 1
+	my $weight = "$throw-weight.csv"; 
 	sub weight
 	{	
 		say $tee "Scaling results for case $countcaseplus, block $contblocksplus.";
-		open( SELECTEDMIXED, $selectmixed ) or die( "$!" ); #say TOFILE "dump(\$selectmixed IN SUB weight ): " . dump($selectmixed);
-		my @lines = <SELECTEDMIXED>; #say TOFILE "dump(SELECTEDMIXED \@lines): " . dump(@lines); 
+		open( SELECTEDMIXED, $selectmixed ) or die( "$!" ); 
+		my @lines = <SELECTEDMIXED>; 
 		close SELECTEDMIXED;
 		my $counterline = 0;
 		open( WEIGHT, ">$weight" ) or die( "$!" );
@@ -266,14 +266,14 @@ sub descend
 			{
 				if ( Sim::OPT::odd($countel) )
 				{
-					push ( @{$containerone[$countcol]}, $elt); #print TOFILE "ELT: $elt\n";
+					push ( @{$containerone[$countcol]}, $elt); 
 					$countcol++;
 				}
 				push (@containernames, $touse);
 				$countel++;
 			}
 		} 
-		#say TOFILE "dump(SELECTEDMIXED \@containernames): " . dump(@containernames); 
+		
 			
 		my @containertwo;
 		my @containerthree;
@@ -371,7 +371,7 @@ sub descend
 			$counterline++;
 		}
 		close WEIGHT;
-		#print TOFILE "CONTAINERTHREE: " . Dumper(@containerthree) . "\n";
+		
 	}
 	&weight(); #
 	
@@ -379,10 +379,10 @@ sub descend
 	sub weighttwo
 	{
 		say $tee "Weighting results for case $countcaseplus, block $contblocksplus.";
-		open( WEIGHT, $weight ); #say TOFILE "dump(\$weight IN SUB weighttwo): " . dump($weight);
+		open( WEIGHT, $weight ); 
 		my @lines = <WEIGHT>;
 		close WEIGHT;
-		open( WEIGHTTWO, ">$weighttwo" ); #say TOFILE "dump(\$weighttwo): " . dump($weighttwo);
+		open( WEIGHTTWO, ">$weighttwo" ); 
 		my $counterline;
 		foreach my $line (@lines)
 		{
@@ -399,9 +399,9 @@ sub descend
 				if ($counterelt > ( $#elts - $numberels ))
 				{
 					print TOFILE "ELT: $elt\n";
-					$newelt = ( $elt * abs($weights[$counterin]) ); # print TOFILE "NEWELT: $newelt\n";
+					$newelt = ( $elt * abs($weights[$counterin]) ); 
 					print TOFILE "ABS" . abs($weights[$counterin]) . "\n";
-					$sum = ( $sum + $newelt ) ; # print TOFILE "SUM: $sum\n";
+					$sum = ( $sum + $newelt ) ; 
 					$counterin++;
 				}
 				$counterelt++;
@@ -428,14 +428,14 @@ sub descend
 	}
 	&weighttwo();	
 	
-	#say TOFILE "dump(\$repfile BEFORE SUB sortmixed): " . dump( $repfile );
-	my $sortmixed = "$repfile-sortmixed.csv"; #say TOFILE "dump(\$sortmixed BEFORE SUB sortmixed): " . dump( $sortmixed );
+	
+	my $sortmixed = "$repfile-sortmixed.csv"; 
 	#if ($repfile) { $sortmixed = "$repfile-sortmixed.csv"; } else { die( "$!" ); } # globsAL!
 	sub sortmixed
 	{
 		say $tee "Processing results for case $countcaseplus, block $contblocksplus.";
-		open( WEIGHTTWO, $weighttwo ) or die( "$!" ); #say TOFILE "dump(\$weighttwo IN SUB sortmixed): " . dump($weighttwo);
-		open( SORTMIXED_, ">$sortmixed" ) or die( "$!" ); #say TOFILE "dump(\$sortmixed): " . dump($sortmixed);
+		open( WEIGHTTWO, $weighttwo ) or die( "$!" ); 
+		open( SORTMIXED_, ">$sortmixed" ) or die( "$!" ); 
 		my @lines = <WEIGHTTWO>;
 		close WEIGHTTWO;
 		my $count = 0;
@@ -462,7 +462,7 @@ sub descend
 		
 		#my @sorted = sort { $b->[1] <=> $a->[1] } @lines;
 		
-		#print SORTMIXED_ map $_->[0],
+		
 		#sort { $a->[$#eltstemp] <=> $b->[$#eltstemp] }
 		#map { [ [ @lines ] , /,/ ] }
 		#foreach my $elt (@sorted)
@@ -471,7 +471,7 @@ sub descend
 		#}
 
 		#if ($numberelts > 0) { print SORTMIXED_ `sort -n -k$numberelts,$numberelts -t , $weighttwo`; } ### ZZZ
-		# print SORTMIXED_ `sort -n -k$numberelts -n $weighttwo`; 
+		
 		close SORTMIXED_;
 	}
 	&sortmixed;
@@ -483,8 +483,8 @@ sub descend
 	{
 		#my $pass_signal = ""; # IF VOID, GAUSS SEIDEL METHOD. IF 0, JACOBI METHOD. ...
 		
-		#say TOFILE `cat $sortmixed`;
-		#say TOFILE "TAKEOPTIMA cat \$sortmixed: $sortmixed";
+		
+		
 		
 		open( SORTMIXED_, $sortmixed ) or die( "$!" );
 		my @lines = <SORTMIXED_>;
@@ -494,9 +494,9 @@ sub descend
 		chomp $winnerentry;
 		
 		my @winnerelms = split(/\s+|,/, $winnerentry);
-		my $winnerline = $winnerelms[0]; #say TOFILE "dump(TAKEOPTIMA\$winnerline): " . dump($winnerline);
+		my $winnerline = $winnerelms[0]; 
 		my $winnerval = $winnerelms[$#winnerelms];
-		push ( @{ $uplift[$countcase][$countblock] }, $winnerval); #say TOFILE "TAKEOPTIMA->\@winneritems " . dump(@winneritems);
+		push ( @{ $uplift[$countcase][$countblock] }, $winnerval); 
 		
 		my $message;
 		unless ( ( "$^O" eq "MSWin32" ) or ( "$^O" eq "MSWin64" ) ) 
@@ -530,34 +530,34 @@ sub descend
 		
 		my $copy = $winnerline;
 		$copy =~ s/$mypath\/$file//;
-		my @taken = Sim::OPT::extractcase("$copy", \%mids); #say TOFILE "TAKEOPTIMA--->taken: " . dump(@taken);
-		my $newtarget = $taken[0]; #say TOFILE "TAKEOPTIMA\$newtarget--->: $newtarget";
+		my @taken = Sim::OPT::extractcase("$copy", \%mids); 
+		my $newtarget = $taken[0]; 
 		$newtarget =~ s/$mypath\///;
-		my %newcarrier = %{$taken[1]}; #say TOFILE "TAKEOPTIMA\%newcarrier--->" . dump(%newcarrier);
+		my %newcarrier = %{$taken[1]}; 
 		say TOFILE "TAKEOPTIMA BEFORE->\@miditers: " . dump(@miditers);
-		%{ $miditers[$countcase] } = %newcarrier; #say TOFILE "TAKEOPTIMA AFTER->\@miditers: " . dump(@miditers);
+		%{ $miditers[$countcase] } = %newcarrier; 
+		
+		
+		
+		
+		
+		
+		
+		
+		
+		
+		
+		
+		
+		
+		
 		
-		#say "2\$countcase : " . dump($countcase);
-		#say "2\@rootnames : " . dump(@rootnames);
-		#say "2\$countblock : " . dump($countblock);
-		#say "2\@sweeps : " . dump(@sweeps);
-		#say "2\@varinumbers : " . dump(@varinumbers);
-		#say "2\@miditers : " . dump(@miditers);
-		#say "2\@winneritems : " . dump(@winneritems);
-		#say "2\@morphcases : " . dump(@morphcases);
-		#say "2\@morphstruct : " . dump(@morphstruct);
 		
-		#say TOFILE "TAKEOPTIMA FINAL ->\$countcase " . dump($countcase);
-		#say TOFILE "TAKEOPTIMA FINAL ->\$countblock " . dump($countblock);
-		#say TOFILE "TAKEOPTIMA FINAL ->\@miditers " . dump(@miditers);
-		#say TOFILE "TAKEOPTIMA FINAL ->\@winneritems " . dump(@winneritems);
-		#say TOFILE "TAKEOPTIMA FINAL ->\%dirfiles " . dump(%dirfiles);
-		#say TOFILE "TAKEOPTIMA FINAL ->\@uplift " . dump(@uplift);
 		
 		$countblock++; ### !!!
 		
-		#say $tee "TAKEOPTIMA FINAL ->\$countblock " . dump($countblock);
-		#say $tee "TAKEOPTIMA FINAL ->\scalar( \@blocks ) " . dump( scalar( @blocks ) );
+		
+		
 		
 		# STOP CONDITION
 		if ( $countblock == scalar( @blocks ) ) # NUMBER OF BLOCK OF THE CURRENT CASE
